#!/bin/sh
# this script with download the user defined vanilladpup 11 development build
# check in https://vanilla-dpup.github.io for the latest 11.0.X version
# v0.3

[ ! $1 ] && echo "Please type the vanilladpup 11 version you want to download" \
	|| echo "Building Vanilladpup 11.0."$1" "

# Make sure we are root incase is not a puppy
[ "`whoami`" != "root" ] && exec sudo -A ${0} ${@}

# Set up 
rm -rf img_to_iso # comment out if you want to keep everything
#rm -rf img_to_iso/ISO # comment out if you want keep iso data
mkdir -p img_to_iso
cd img_to_iso/
WD=$(pwd)
mkdir -p p1
mkdir -p p2
mkdir -p ISO

if [ "$(pwd | cut -f2 -d/)" = "home" ]; then
	FREEDISK=$(df -m |  egrep /$ | tail -1 | tr -s ' ' | cut -f4 -d' ')
else
	DISK=$(pwd | cut -f1-3 -d/)
	FREEDISK=$(df -m | grep "$DISK" | tr -s ' ' | cut -f4 -d' ')
fi
[ "$FREEDISK" -le 5000 ] && echo "At least 6GB of free sace is needed" &&  exit 1 

# Exit on any error
set -e

# The path or the name format of the download may be changed by the developer
# If the download fails change the line bellow accordingly 
echo "Getting vanilla dpup 11 build"
[ ! -f "vanilladpup-11.0."$1"-labwc-uefi.img.gz" -a ! -f vanilladpup-11.0."$1"-labwc-uefi.img ] && wget -c \
	https://github.com/vanilla-dpup/unstable/releases/download/vanilladpup-x86_64-11.0."$1"/vanilladpup-11.0."$1"-labwc-uefi.img.gz
sync

#extract image
echo "Expanding  vanilla dpup 11 tarball"
[ ! -f vanilladpup-11.0."$1"-labwc-uefi.img ] && gunzip  vanilladpup-11.0."$1"-labwc-uefi.img.gz 
sync

echo "Copying build files"
# Find first free loop and mount image partition
LOOP=$(losetup --find)
losetup -fP vanilladpup-11.0."$1"-labwc-uefi.img
#losetup "$LOOP"
mount "$LOOP"p1 p1
mount "$LOOP"p2 p2
sync
# copy files to the ISO
cp -aR p1/* ISO/
cp -aR p2/* ISO/
sync
# Cleanup
umount -f $(pwd)/p1
umount -f $(pwd)/p2
losetup -d "$LOOP" 
rm -rf p1 p2
rm -rf ISO/lost+found/
rm -rf ISO/vanilladpupsave/

# get the bookworm ISO 
echo "Getting bookworm ISO"
[ ! -f "BookwormPup64_10.0.7.iso" ] && \
	wget -c https://rockedge.org/kernels/data/ISO/Bookworm_Pup64/BookwormPup64_10.0.7.iso
mkdir disk
mount BookwormPup64_10.0.7.iso disk/
cp -aR disk/boot ISO/
cp -a disk/grub.cfg ISO/
cp -a disk/isolinux.bin ISO/
cp -a ../splash\.* ISO/boot/
sync

# mod boot menu to vanilladpup
echo "Adapt the boot menu"
sed -i "s/BookwormPup64 10.0.7/vanilladpup 11.0."$1"/g" ISO/boot/grub/grub.cfg 
sed -i "s/BookwormPup64 10.0.7/vanilladpup 11.0."$1"/g" ISO/grub.cfg 
sed -i "s/BookwormPup64 10.0.7/vanilladpup 11.0."$1"/g" ISO/boot/grub/loopback.cfg 
sed -i "s/BookwormPup64 10.0.7/vanilladpup 11.0."$1"/g" ISO/boot/grub/menu.lst 
sed -i "s/initrd.gz/initrd.zst/g" ISO/boot/grub/grub.cfg 
sed -i "s/initrd.gz/initrd.zst/g" ISO/grub.cfg 
sed -i "s/initrd.gz/initrd.zst/g" ISO/boot/grub/loopback.cfg 
sed -i "s/initrd.gz/initrd.zst/g" ISO/boot/grub/menu.lst 
umount disk
rm -rf disk
sync
echo "Building the ISO"
rm -f ../vanilladpup-11.0."$1"-labwc-uefi.iso 2>/dev/null
mkisofs -iso-level 4 -D -R -o ../vanilladpup-11.0."$1"-labwc-uefi.iso -b isolinux.bin \
	 -no-emul-boot -boot-load-size 4 -boot-info-table -c boot/boot.catalog ISO/

sync

echo "The vanilladpup-11.0."$1"-labwc-uefi.iso is build. Boot to test 1t!"
